@@ -1,4 +1,3 @@
-use 5.010000;
 use strict;
 use warnings;
 
@@ -7,7 +6,7 @@ BEGIN {
   $Dist::Zilla::Plugin::Prereqs::DarkPAN::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::Plugin::Prereqs::DarkPAN::VERSION = '0.2.3';
+  $Dist::Zilla::Plugin::Prereqs::DarkPAN::VERSION = '0.2.4';
 }
 
 # ABSTRACT: Depend on things from arbitrary places-not-CPAN
@@ -49,7 +48,8 @@ has _deps => ( is => 'ro', isa => 'HashRef', default => sub { {} }, );
 
 sub _add_dep {
   my ( $class, $stash, $args ) = @_;
-  my $ds = ( $stash->{deps} //= {} );
+  $stash->{deps} = {} unless exists $stash->{deps};
+  my $ds     = $stash->{deps};
   my $logger = $stash->{logger};
 
   my $key   = $args->{key};
@@ -68,8 +68,10 @@ sub _add_dep {
 sub _add_attribute {
   my ( $class, $stash, $args ) = @_;
 
-  my $attributes = ( $stash->{attributes} //= {} );
-  my $logger = $stash->{logger};
+  $stash->{attributes} = {} unless exists $stash->{attributes};
+
+  my $attributes = $stash->{attributes};
+  my $logger     = $stash->{logger};
 
   my $key       = $args->{key};
   my $attribute = $args->{attribute};
@@ -80,7 +82,7 @@ sub _add_attribute {
   return $logger->log_fatal( [ 'Attribute \'%s\' for key \'%s\' not supported.', $attribute, $key, ], )
     if not exists $supported_attrs->{$attribute};
 
-  $attributes->{$key} //= {};
+  $attributes->{$key} = {} unless exists $attributes->{$key};
 
   return $logger->log_fatal( [ 'tried to set attribute \'%s\' for %s more than once.', $attribute, $key, ] )
     if exists $attributes->{$key}->{$attribute};
@@ -149,12 +151,16 @@ sub BUILDARGS {
   }
   for my $dep ( keys %{$deps} ) {
     require Dist::Zilla::ExternalPrereq;
+    my $edep = $attributes->{$dep};
+    $edep = {} unless defined $edep;
+
     my $instance = Dist::Zilla::ExternalPrereq->new(
       name        => $dep,
       plugin_name => $name . '{ExternalPrereq: dep on=\'' . $dep . '\'}',
       zilla       => $zilla,
       baseurl     => $deps->{$dep},
-      %{ $attributes->{$dep} // {} }
+
+      %{$edep}
     );
     $_deps->{$dep} = $instance;
   }
@@ -200,7 +206,7 @@ Dist::Zilla::Plugin::Prereqs::DarkPAN - Depend on things from arbitrary places-n
 
 =head1 VERSION
 
-version 0.2.3
+version 0.2.4
 
 =head1 SYNOPSIS
 
